      FUNCTION SPLNVL(COEFF,DX,DX2DV2,DX3DV6)
C*******************************************************************
C
C   NAME- SPLNVL
C
C   LANGUAGE- VS FORTRAN     TYPE- FUNCTION    COMPUTER- HDS9000
C
C   VERSION- 1.0      DATE- 12/17/91     PROGRAMMER- CARLA NEIGH, SMSRC
C   VERSION- 3.0      DATE- 06/04/96     PROGRAMMER- TIM GARDNER (HSTX)
C
C   FUNCTION- THIS REAL*4 FUNCTION RETURNS THE FUNCTIONAL VALUE,
C             FOR A SPECIFIC DATA POINT, OF THE PIECEWISE CUBIC
C             POLYNOMIAL REPRESENTATION OF A FUNCTION GIVEN BY A
C             SET OF DATA POINTS AND THEIR CORRESPONDING SPLINE
C             COEFFICIENTS.  THE FUNCTIONAL VALUE IS COMPUTED
C             USING THE FOLLOWING EQUATION:
C              P(X,I) = C(1,I) + C(2,I) (X - X(I)) +
C                       (1/2) C(3,I) (X - X(I))**2 +
C                       (1/6) C(4,I) (X - X(I))**3
C
C   VERSION 3.0- DOCUMENTATION AND SYNTAX CHANGES FOR ATOVS BASELINE
C                ON THE CRAY.
C
C   CALLING SEQUENCE PARAMETERS-
C   NAME    TYPE   I/O   DESCRIPTION
C   ----    ----   ---   -----------
C   COEFF   REAL    I    VECTOR (DIMENSIONED 4) CONTAINING THE
C                        HERMITE POLYNOMIAL COEFFICIENTS FOR THE
C                        DATA POINT AT THE LOWER BOUND OF THE
C                        INTERVAL CONTAINING THE POINT FOR WHICH
C                        THE FUNCTIONAL VALUE IS TO BE RETURNED
C   DX      REAL    I    THE DIFFERENCE BETWEEN THE POINT AT WHICH
C                        THE FUNCTIONAL VALUE IS TO BE COMPUTED, AND
C                        THE LOWER BOUND OF THE INTERVAL CONTAINING
C                        THE POINT:  (X - X(I))
C   DX2DV2  REAL    I    THE VALUE OF DX SQUARED DIVIDED BY 2:
C                        (1/2) (X - X(I))**2
C   DX3DV6  REAL    I    THE VALUE OF DX CUBED DIVIDED BY 6:
C                        (1/6) (X - X(I))**3
C
C
C   EXIT STATES- NONE
C
C   COMMENTS-
C     SEE THE FOLLOWING REFERENCES:
C       DE BOOR, CARL,1978: A PRACTICAL GUIDE TO SPLINES, SPRINGER-
C          VERLAG, 392 PP.
C       HYMAN, JAMES M.,1983: ACCURATE MONOTONICITY PRESERVING CUBIC
C          INTERPOLATION, SIAM J.SCI.STAT.COMPUT., 4, 645-654.
C
C*****************************************************************
C
      REAL SPLNVL, COEFF(4), DX, DX2DV2, DX3DV6
C
C  COMPUTE THE SPLINE VALUE.
C
      SPLNVL = COEFF(1) + (COEFF(2) * DX) + (COEFF(3) * DX2DV2) +
     1         (COEFF(4) * DX3DV6)
C
      RETURN
      END
